/* Automatically @generated by tree-sitter v0.25.8 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 138
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 69
#define ALIAS_COUNT 0
#define TOKEN_COUNT 27
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 7
#define MAX_ALIAS_SEQUENCE_LENGTH 8
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 6
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_BANG = 1,
  anon_sym_LF = 2,
  anon_sym_end = 3,
  anon_sym_EQ = 4,
  anon_sym_SEMI = 5,
  anon_sym_COMMA = 6,
  anon_sym_LBRACK = 7,
  anon_sym_RBRACK = 8,
  anon_sym_PERCENT = 9,
  anon_sym_STAR = 10,
  anon_sym_xyz = 11,
  anon_sym_int = 12,
  anon_sym_gzmt = 13,
  anon_sym_xyzfile = 14,
  anon_sym_gzmtfile = 15,
  anon_sym_LBRACE = 16,
  anon_sym_RBRACE = 17,
  sym_comment = 18,
  sym_element = 19,
  sym_word = 20,
  sym_string = 21,
  sym_quoted_string = 22,
  sym_float = 23,
  sym_integer = 24,
  sym_file = 25,
  sym_arg = 26,
  sym_source_file = 27,
  sym_simple_line = 28,
  sym__input = 29,
  sym_input_line = 30,
  sym_input_block = 31,
  sym_input_body = 32,
  sym_subblock = 33,
  sym_kv_pair = 34,
  sym_variable_def = 35,
  sym_variable_name = 36,
  sym_variable_range = 37,
  sym_variable_array = 38,
  sym_value = 39,
  sym_value_atom = 40,
  sym_input_key = 41,
  sym_input_title = 42,
  sym__geom = 43,
  sym_geom_line = 44,
  sym_geom_block = 45,
  sym_geom_line_types = 46,
  sym_int_line = 47,
  sym_zmat_line1 = 48,
  sym_zmat_line2 = 49,
  sym_zmat_line3 = 50,
  sym_zmat_line4 = 51,
  sym_xyz_line = 52,
  sym_coord_value = 53,
  sym_variable_ref = 54,
  sym_array = 55,
  sym_brace_block = 56,
  sym_brace_content = 57,
  sym_brace_value = 58,
  sym_raw_content = 59,
  aux_sym_source_file_repeat1 = 60,
  aux_sym_simple_line_repeat1 = 61,
  aux_sym_input_body_repeat1 = 62,
  aux_sym_subblock_repeat1 = 63,
  aux_sym_subblock_repeat2 = 64,
  aux_sym_subblock_repeat3 = 65,
  aux_sym_variable_array_repeat1 = 66,
  aux_sym_value_repeat1 = 67,
  aux_sym_brace_content_repeat1 = 68,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_BANG] = "!",
  [anon_sym_LF] = "\n",
  [anon_sym_end] = "end",
  [anon_sym_EQ] = "=",
  [anon_sym_SEMI] = ";",
  [anon_sym_COMMA] = ",",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_PERCENT] = "%",
  [anon_sym_STAR] = "*",
  [anon_sym_xyz] = "xyz",
  [anon_sym_int] = "int",
  [anon_sym_gzmt] = "gzmt",
  [anon_sym_xyzfile] = "xyzfile",
  [anon_sym_gzmtfile] = "gzmtfile",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [sym_comment] = "comment",
  [sym_element] = "element",
  [sym_word] = "word",
  [sym_string] = "string",
  [sym_quoted_string] = "quoted_string",
  [sym_float] = "float",
  [sym_integer] = "integer",
  [sym_file] = "file",
  [sym_arg] = "arg",
  [sym_source_file] = "source_file",
  [sym_simple_line] = "simple_line",
  [sym__input] = "_input",
  [sym_input_line] = "input_line",
  [sym_input_block] = "input_block",
  [sym_input_body] = "input_body",
  [sym_subblock] = "subblock",
  [sym_kv_pair] = "kv_pair",
  [sym_variable_def] = "variable_def",
  [sym_variable_name] = "variable_name",
  [sym_variable_range] = "variable_range",
  [sym_variable_array] = "variable_array",
  [sym_value] = "value",
  [sym_value_atom] = "value_atom",
  [sym_input_key] = "input_key",
  [sym_input_title] = "input_title",
  [sym__geom] = "_geom",
  [sym_geom_line] = "geom_line",
  [sym_geom_block] = "geom_block",
  [sym_geom_line_types] = "geom_line_types",
  [sym_int_line] = "int_line",
  [sym_zmat_line1] = "zmat_line1",
  [sym_zmat_line2] = "zmat_line2",
  [sym_zmat_line3] = "zmat_line3",
  [sym_zmat_line4] = "zmat_line4",
  [sym_xyz_line] = "xyz_line",
  [sym_coord_value] = "coord_value",
  [sym_variable_ref] = "variable_ref",
  [sym_array] = "array",
  [sym_brace_block] = "brace_block",
  [sym_brace_content] = "brace_content",
  [sym_brace_value] = "brace_value",
  [sym_raw_content] = "raw_content",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_simple_line_repeat1] = "simple_line_repeat1",
  [aux_sym_input_body_repeat1] = "input_body_repeat1",
  [aux_sym_subblock_repeat1] = "subblock_repeat1",
  [aux_sym_subblock_repeat2] = "subblock_repeat2",
  [aux_sym_subblock_repeat3] = "subblock_repeat3",
  [aux_sym_variable_array_repeat1] = "variable_array_repeat1",
  [aux_sym_value_repeat1] = "value_repeat1",
  [aux_sym_brace_content_repeat1] = "brace_content_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_LF] = anon_sym_LF,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_xyz] = anon_sym_xyz,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_gzmt] = anon_sym_gzmt,
  [anon_sym_xyzfile] = anon_sym_xyzfile,
  [anon_sym_gzmtfile] = anon_sym_gzmtfile,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [sym_comment] = sym_comment,
  [sym_element] = sym_element,
  [sym_word] = sym_word,
  [sym_string] = sym_string,
  [sym_quoted_string] = sym_quoted_string,
  [sym_float] = sym_float,
  [sym_integer] = sym_integer,
  [sym_file] = sym_file,
  [sym_arg] = sym_arg,
  [sym_source_file] = sym_source_file,
  [sym_simple_line] = sym_simple_line,
  [sym__input] = sym__input,
  [sym_input_line] = sym_input_line,
  [sym_input_block] = sym_input_block,
  [sym_input_body] = sym_input_body,
  [sym_subblock] = sym_subblock,
  [sym_kv_pair] = sym_kv_pair,
  [sym_variable_def] = sym_variable_def,
  [sym_variable_name] = sym_variable_name,
  [sym_variable_range] = sym_variable_range,
  [sym_variable_array] = sym_variable_array,
  [sym_value] = sym_value,
  [sym_value_atom] = sym_value_atom,
  [sym_input_key] = sym_input_key,
  [sym_input_title] = sym_input_title,
  [sym__geom] = sym__geom,
  [sym_geom_line] = sym_geom_line,
  [sym_geom_block] = sym_geom_block,
  [sym_geom_line_types] = sym_geom_line_types,
  [sym_int_line] = sym_int_line,
  [sym_zmat_line1] = sym_zmat_line1,
  [sym_zmat_line2] = sym_zmat_line2,
  [sym_zmat_line3] = sym_zmat_line3,
  [sym_zmat_line4] = sym_zmat_line4,
  [sym_xyz_line] = sym_xyz_line,
  [sym_coord_value] = sym_coord_value,
  [sym_variable_ref] = sym_variable_ref,
  [sym_array] = sym_array,
  [sym_brace_block] = sym_brace_block,
  [sym_brace_content] = sym_brace_content,
  [sym_brace_value] = sym_brace_value,
  [sym_raw_content] = sym_raw_content,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_simple_line_repeat1] = aux_sym_simple_line_repeat1,
  [aux_sym_input_body_repeat1] = aux_sym_input_body_repeat1,
  [aux_sym_subblock_repeat1] = aux_sym_subblock_repeat1,
  [aux_sym_subblock_repeat2] = aux_sym_subblock_repeat2,
  [aux_sym_subblock_repeat3] = aux_sym_subblock_repeat3,
  [aux_sym_variable_array_repeat1] = aux_sym_variable_array_repeat1,
  [aux_sym_value_repeat1] = aux_sym_value_repeat1,
  [aux_sym_brace_content_repeat1] = aux_sym_brace_content_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xyz] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gzmt] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xyzfile] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gzmtfile] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_element] = {
    .visible = true,
    .named = true,
  },
  [sym_word] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_string] = {
    .visible = true,
    .named = true,
  },
  [sym_float] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_file] = {
    .visible = true,
    .named = true,
  },
  [sym_arg] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_line] = {
    .visible = true,
    .named = true,
  },
  [sym__input] = {
    .visible = false,
    .named = true,
  },
  [sym_input_line] = {
    .visible = true,
    .named = true,
  },
  [sym_input_block] = {
    .visible = true,
    .named = true,
  },
  [sym_input_body] = {
    .visible = true,
    .named = true,
  },
  [sym_subblock] = {
    .visible = true,
    .named = true,
  },
  [sym_kv_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_def] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_name] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_range] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_array] = {
    .visible = true,
    .named = true,
  },
  [sym_value] = {
    .visible = true,
    .named = true,
  },
  [sym_value_atom] = {
    .visible = true,
    .named = true,
  },
  [sym_input_key] = {
    .visible = true,
    .named = true,
  },
  [sym_input_title] = {
    .visible = true,
    .named = true,
  },
  [sym__geom] = {
    .visible = false,
    .named = true,
  },
  [sym_geom_line] = {
    .visible = true,
    .named = true,
  },
  [sym_geom_block] = {
    .visible = true,
    .named = true,
  },
  [sym_geom_line_types] = {
    .visible = true,
    .named = true,
  },
  [sym_int_line] = {
    .visible = true,
    .named = true,
  },
  [sym_zmat_line1] = {
    .visible = true,
    .named = true,
  },
  [sym_zmat_line2] = {
    .visible = true,
    .named = true,
  },
  [sym_zmat_line3] = {
    .visible = true,
    .named = true,
  },
  [sym_zmat_line4] = {
    .visible = true,
    .named = true,
  },
  [sym_xyz_line] = {
    .visible = true,
    .named = true,
  },
  [sym_coord_value] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_ref] = {
    .visible = true,
    .named = true,
  },
  [sym_array] = {
    .visible = true,
    .named = true,
  },
  [sym_brace_block] = {
    .visible = true,
    .named = true,
  },
  [sym_brace_content] = {
    .visible = true,
    .named = true,
  },
  [sym_brace_value] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_content] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_simple_line_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_input_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subblock_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subblock_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subblock_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_array_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_value_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_brace_content_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_connect1 = 1,
  field_connect2 = 2,
  field_connect3 = 3,
  field_name = 4,
  field_zmat_atom1 = 5,
  field_zmat_atom2 = 6,
  field_zmat_atom3 = 7,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_connect1] = "connect1",
  [field_connect2] = "connect2",
  [field_connect3] = "connect3",
  [field_name] = "name",
  [field_zmat_atom1] = "zmat_atom1",
  [field_zmat_atom2] = "zmat_atom2",
  [field_zmat_atom3] = "zmat_atom3",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 2},
  [4] = {.index = 4, .length = 3},
  [5] = {.index = 7, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 0},
  [1] =
    {field_zmat_atom1, 1},
  [2] =
    {field_zmat_atom1, 1},
    {field_zmat_atom2, 3},
  [4] =
    {field_connect1, 1},
    {field_connect2, 2},
    {field_connect3, 3},
  [7] =
    {field_zmat_atom1, 1},
    {field_zmat_atom2, 3},
    {field_zmat_atom3, 5},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 16,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 95,
  [98] = 98,
  [99] = 92,
  [100] = 98,
  [101] = 91,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 119,
  [134] = 118,
  [135] = 135,
  [136] = 136,
  [137] = 137,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(30);
      ADVANCE_MAP(
        '!', 31,
        '"', 6,
        '#', 54,
        '%', 40,
        '*', 41,
        ',', 37,
        '-', 87,
        ';', 36,
        '=', 35,
        '[', 38,
        ']', 39,
        'e', 59,
        'g', 64,
        'i', 60,
        'x', 63,
        '{', 52,
        '}', 53,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(83);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(68);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(32);
      if (lookahead == '"') ADVANCE(6);
      if (lookahead == '#') ADVANCE(54);
      if (lookahead == '-') ADVANCE(87);
      if (lookahead == '=') ADVANCE(35);
      if (lookahead == '[') ADVANCE(38);
      if (lookahead == '{') ADVANCE(52);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(83);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(78);
      END_STATE();
    case 2:
      if (lookahead == '\n') ADVANCE(32);
      if (lookahead == '#') ADVANCE(54);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(90);
      END_STATE();
    case 3:
      if (lookahead == '\n') ADVANCE(32);
      if (lookahead == '#') ADVANCE(54);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(88);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '"', 6,
        '#', 54,
        ',', 37,
        '-', 29,
        ';', 36,
        '[', 38,
        'e', 76,
        '{', 52,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(84);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 5:
      if (lookahead == '"') ADVANCE(6);
      if (lookahead == '#') ADVANCE(54);
      if (lookahead == '-') ADVANCE(87);
      if (lookahead == '=') ADVANCE(35);
      if (lookahead == '{') ADVANCE(52);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(83);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(78);
      END_STATE();
    case 6:
      if (lookahead == '"') ADVANCE(82);
      if (lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(6);
      END_STATE();
    case 7:
      if (lookahead == '#') ADVANCE(54);
      if (lookahead == '*') ADVANCE(41);
      if (lookahead == '-') ADVANCE(29);
      if (lookahead == ']') ADVANCE(39);
      if (lookahead == 'e') ADVANCE(59);
      if (lookahead == '{') ADVANCE(52);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(84);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(68);
      END_STATE();
    case 8:
      if (lookahead == '#') ADVANCE(54);
      if (lookahead == '*') ADVANCE(41);
      if (lookahead == 'e') ADVANCE(61);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(88);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(67);
      END_STATE();
    case 9:
      if (lookahead == '#') ADVANCE(54);
      if (lookahead == 'g') ADVANCE(25);
      if (lookahead == 'i') ADVANCE(21);
      if (lookahead == 'x') ADVANCE(24);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      END_STATE();
    case 10:
      if (lookahead == '#') ADVANCE(54);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 11:
      if (lookahead == '#') ADVANCE(54);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(88);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(80);
      END_STATE();
    case 12:
      if (lookahead == '#') ADVANCE(54);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(89);
      END_STATE();
    case 13:
      if (lookahead == '-') ADVANCE(28);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(86);
      END_STATE();
    case 14:
      if (lookahead == 'e') ADVANCE(48);
      END_STATE();
    case 15:
      if (lookahead == 'e') ADVANCE(50);
      END_STATE();
    case 16:
      if (lookahead == 'i') ADVANCE(18);
      END_STATE();
    case 17:
      if (lookahead == 'i') ADVANCE(19);
      END_STATE();
    case 18:
      if (lookahead == 'l') ADVANCE(14);
      END_STATE();
    case 19:
      if (lookahead == 'l') ADVANCE(15);
      END_STATE();
    case 20:
      if (lookahead == 'm') ADVANCE(23);
      END_STATE();
    case 21:
      if (lookahead == 'n') ADVANCE(22);
      END_STATE();
    case 22:
      if (lookahead == 't') ADVANCE(44);
      END_STATE();
    case 23:
      if (lookahead == 't') ADVANCE(47);
      END_STATE();
    case 24:
      if (lookahead == 'y') ADVANCE(26);
      END_STATE();
    case 25:
      if (lookahead == 'z') ADVANCE(20);
      END_STATE();
    case 26:
      if (lookahead == 'z') ADVANCE(43);
      END_STATE();
    case 27:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(85);
      END_STATE();
    case 28:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(86);
      END_STATE();
    case 29:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(84);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(32);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_end);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_xyz);
      if (lookahead == 'f') ADVANCE(72);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_xyz);
      if (lookahead == 'f') ADVANCE(16);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_int);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_int);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_gzmt);
      if (lookahead == 'f') ADVANCE(73);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_gzmt);
      if (lookahead == 'f') ADVANCE(17);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(anon_sym_xyzfile);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(anon_sym_xyzfile);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(anon_sym_gzmtfile);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(anon_sym_gzmtfile);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(54);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(sym_element);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'd') ADVANCE(34);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'd') ADVANCE(33);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'm') ADVANCE(77);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'n') ADVANCE(56);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(66);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'n') ADVANCE(62);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(66);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'n') ADVANCE(57);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(55);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 't') ADVANCE(45);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'y') ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(66);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'z') ADVANCE(58);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(66);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'z') ADVANCE(42);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(79);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(sym_element);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym_element);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(55);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(sym_element);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(66);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'd') ADVANCE(34);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'e') ADVANCE(49);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'e') ADVANCE(51);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'i') ADVANCE(74);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'i') ADVANCE(75);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'l') ADVANCE(70);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'l') ADVANCE(71);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'n') ADVANCE(69);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 't') ADVANCE(46);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '"' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(81);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(78);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(sym_word);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(79);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(sym_string);
      if (lookahead == '"' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(81);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(80);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(sym_string);
      if (lookahead == '"' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(81);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(sym_quoted_string);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == '-') ADVANCE(88);
      if (lookahead == '.') ADVANCE(27);
      if (lookahead == 'e') ADVANCE(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(83);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == '.') ADVANCE(27);
      if (lookahead == 'e') ADVANCE(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(84);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'e') ADVANCE(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(85);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(sym_float);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(86);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '-') ADVANCE(88);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(83);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(88);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(sym_file);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(89);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(sym_arg);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(90);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 0},
  [2] = {.lex_state = 7},
  [3] = {.lex_state = 4},
  [4] = {.lex_state = 0},
  [5] = {.lex_state = 0},
  [6] = {.lex_state = 4},
  [7] = {.lex_state = 4},
  [8] = {.lex_state = 5},
  [9] = {.lex_state = 5},
  [10] = {.lex_state = 1},
  [11] = {.lex_state = 5},
  [12] = {.lex_state = 8},
  [13] = {.lex_state = 5},
  [14] = {.lex_state = 7},
  [15] = {.lex_state = 8},
  [16] = {.lex_state = 5},
  [17] = {.lex_state = 0},
  [18] = {.lex_state = 9},
  [19] = {.lex_state = 0},
  [20] = {.lex_state = 0},
  [21] = {.lex_state = 4},
  [22] = {.lex_state = 1},
  [23] = {.lex_state = 7},
  [24] = {.lex_state = 4},
  [25] = {.lex_state = 4},
  [26] = {.lex_state = 4},
  [27] = {.lex_state = 4},
  [28] = {.lex_state = 4},
  [29] = {.lex_state = 4},
  [30] = {.lex_state = 0},
  [31] = {.lex_state = 4},
  [32] = {.lex_state = 8},
  [33] = {.lex_state = 4},
  [34] = {.lex_state = 4},
  [35] = {.lex_state = 0},
  [36] = {.lex_state = 8},
  [37] = {.lex_state = 4},
  [38] = {.lex_state = 0},
  [39] = {.lex_state = 0},
  [40] = {.lex_state = 4},
  [41] = {.lex_state = 0},
  [42] = {.lex_state = 4},
  [43] = {.lex_state = 8},
  [44] = {.lex_state = 8},
  [45] = {.lex_state = 4},
  [46] = {.lex_state = 4},
  [47] = {.lex_state = 0},
  [48] = {.lex_state = 0},
  [49] = {.lex_state = 7},
  [50] = {.lex_state = 7},
  [51] = {.lex_state = 0},
  [52] = {.lex_state = 4},
  [53] = {.lex_state = 7},
  [54] = {.lex_state = 7},
  [55] = {.lex_state = 0},
  [56] = {.lex_state = 7},
  [57] = {.lex_state = 7},
  [58] = {.lex_state = 4},
  [59] = {.lex_state = 7},
  [60] = {.lex_state = 7},
  [61] = {.lex_state = 0},
  [62] = {.lex_state = 7},
  [63] = {.lex_state = 4},
  [64] = {.lex_state = 7},
  [65] = {.lex_state = 7},
  [66] = {.lex_state = 0},
  [67] = {.lex_state = 8},
  [68] = {.lex_state = 7},
  [69] = {.lex_state = 7},
  [70] = {.lex_state = 2},
  [71] = {.lex_state = 8},
  [72] = {.lex_state = 4},
  [73] = {.lex_state = 4},
  [74] = {.lex_state = 7},
  [75] = {.lex_state = 4},
  [76] = {.lex_state = 0},
  [77] = {.lex_state = 0},
  [78] = {.lex_state = 2},
  [79] = {.lex_state = 4},
  [80] = {.lex_state = 7},
  [81] = {.lex_state = 8},
  [82] = {.lex_state = 2},
  [83] = {.lex_state = 4},
  [84] = {.lex_state = 8},
  [85] = {.lex_state = 8},
  [86] = {.lex_state = 7},
  [87] = {.lex_state = 0},
  [88] = {.lex_state = 8},
  [89] = {.lex_state = 4},
  [90] = {.lex_state = 4},
  [91] = {.lex_state = 10},
  [92] = {.lex_state = 7},
  [93] = {.lex_state = 3},
  [94] = {.lex_state = 3},
  [95] = {.lex_state = 7},
  [96] = {.lex_state = 3},
  [97] = {.lex_state = 3},
  [98] = {.lex_state = 11},
  [99] = {.lex_state = 3},
  [100] = {.lex_state = 11},
  [101] = {.lex_state = 10},
  [102] = {.lex_state = 1},
  [103] = {.lex_state = 8},
  [104] = {.lex_state = 1},
  [105] = {.lex_state = 8},
  [106] = {.lex_state = 8},
  [107] = {.lex_state = 10},
  [108] = {.lex_state = 0},
  [109] = {.lex_state = 8},
  [110] = {.lex_state = 8},
  [111] = {.lex_state = 1},
  [112] = {.lex_state = 8},
  [113] = {.lex_state = 7},
  [114] = {.lex_state = 8},
  [115] = {.lex_state = 8},
  [116] = {.lex_state = 1},
  [117] = {.lex_state = 7},
  [118] = {.lex_state = 0},
  [119] = {.lex_state = 0},
  [120] = {.lex_state = 1},
  [121] = {.lex_state = 7},
  [122] = {.lex_state = 8},
  [123] = {.lex_state = 0},
  [124] = {.lex_state = 12},
  [125] = {.lex_state = 8},
  [126] = {.lex_state = 1},
  [127] = {.lex_state = 1},
  [128] = {.lex_state = 0},
  [129] = {.lex_state = 8},
  [130] = {.lex_state = 8},
  [131] = {.lex_state = 1},
  [132] = {.lex_state = 8},
  [133] = {.lex_state = 0},
  [134] = {.lex_state = 0},
  [135] = {.lex_state = 8},
  [136] = {.lex_state = 0},
  [137] = {.lex_state = 1},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_xyz] = ACTIONS(1),
    [anon_sym_int] = ACTIONS(1),
    [anon_sym_gzmt] = ACTIONS(1),
    [anon_sym_xyzfile] = ACTIONS(1),
    [anon_sym_gzmtfile] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_element] = ACTIONS(1),
    [sym_word] = ACTIONS(1),
    [sym_quoted_string] = ACTIONS(1),
    [sym_float] = ACTIONS(1),
    [sym_integer] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(123),
    [sym_simple_line] = STATE(5),
    [sym__input] = STATE(5),
    [sym_input_line] = STATE(5),
    [sym_input_block] = STATE(5),
    [sym_input_title] = STATE(3),
    [sym__geom] = STATE(5),
    [sym_geom_line] = STATE(5),
    [sym_geom_block] = STATE(5),
    [aux_sym_source_file_repeat1] = STATE(5),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_BANG] = ACTIONS(7),
    [anon_sym_PERCENT] = ACTIONS(9),
    [anon_sym_STAR] = ACTIONS(11),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13), 1,
      anon_sym_end,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(17), 1,
      sym_element,
    ACTIONS(19), 1,
      sym_word,
    STATE(8), 1,
      sym_input_key,
    STATE(13), 1,
      sym_array,
    STATE(76), 1,
      sym_variable_name,
    STATE(83), 1,
      sym_brace_block,
    STATE(109), 1,
      sym_input_body,
    STATE(43), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
    STATE(44), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
    STATE(7), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
    STATE(15), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [53] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 1,
      sym_word,
    ACTIONS(21), 1,
      anon_sym_end,
    STATE(8), 1,
      sym_input_key,
    STATE(13), 1,
      sym_array,
    STATE(76), 1,
      sym_variable_name,
    STATE(83), 1,
      sym_brace_block,
    STATE(135), 1,
      sym_input_body,
    ACTIONS(23), 2,
      sym_quoted_string,
      sym_float,
    STATE(7), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
  [92] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(25), 1,
      ts_builtin_sym_end,
    ACTIONS(27), 1,
      anon_sym_BANG,
    ACTIONS(30), 1,
      anon_sym_PERCENT,
    ACTIONS(33), 1,
      anon_sym_STAR,
    STATE(3), 1,
      sym_input_title,
    STATE(4), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_source_file_repeat1,
  [121] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_BANG,
    ACTIONS(9), 1,
      anon_sym_PERCENT,
    ACTIONS(11), 1,
      anon_sym_STAR,
    ACTIONS(36), 1,
      ts_builtin_sym_end,
    STATE(3), 1,
      sym_input_title,
    STATE(4), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_source_file_repeat1,
  [150] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(38), 1,
      anon_sym_end,
    ACTIONS(40), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      sym_word,
    STATE(8), 1,
      sym_input_key,
    STATE(13), 1,
      sym_array,
    STATE(76), 1,
      sym_variable_name,
    STATE(83), 1,
      sym_brace_block,
    STATE(6), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
  [182] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 1,
      sym_word,
    ACTIONS(46), 1,
      anon_sym_end,
    STATE(8), 1,
      sym_input_key,
    STATE(13), 1,
      sym_array,
    STATE(76), 1,
      sym_variable_name,
    STATE(83), 1,
      sym_brace_block,
    STATE(6), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
  [214] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(48), 1,
      anon_sym_EQ,
    ACTIONS(50), 1,
      sym_word,
    ACTIONS(54), 1,
      sym_quoted_string,
    STATE(26), 1,
      sym_value_atom,
    STATE(42), 1,
      sym_value,
    STATE(33), 2,
      sym_array,
      sym_brace_block,
    ACTIONS(52), 3,
      sym_string,
      sym_float,
      sym_integer,
  [245] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(50), 1,
      sym_word,
    ACTIONS(54), 1,
      sym_quoted_string,
    STATE(26), 1,
      sym_value_atom,
    STATE(46), 1,
      sym_value,
    STATE(33), 2,
      sym_array,
      sym_brace_block,
    ACTIONS(52), 3,
      sym_string,
      sym_float,
      sym_integer,
  [273] = 5,
    ACTIONS(56), 1,
      anon_sym_LF,
    ACTIONS(58), 1,
      anon_sym_EQ,
    ACTIONS(61), 1,
      anon_sym_LBRACK,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(64), 6,
      anon_sym_LBRACE,
      sym_word,
      sym_string,
      sym_quoted_string,
      sym_float,
      sym_integer,
  [294] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(50), 1,
      sym_word,
    ACTIONS(54), 1,
      sym_quoted_string,
    STATE(34), 1,
      sym_value_atom,
    STATE(33), 2,
      sym_array,
      sym_brace_block,
    ACTIONS(52), 3,
      sym_string,
      sym_float,
      sym_integer,
  [319] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(70), 1,
      sym_element,
    ACTIONS(68), 2,
      anon_sym_end,
      anon_sym_STAR,
    STATE(12), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [337] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 3,
      anon_sym_EQ,
      anon_sym_LBRACE,
      sym_quoted_string,
    ACTIONS(64), 4,
      sym_word,
      sym_string,
      sym_float,
      sym_integer,
  [352] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(75), 1,
      anon_sym_STAR,
    ACTIONS(77), 1,
      sym_element,
    STATE(12), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [369] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(79), 1,
      anon_sym_end,
    ACTIONS(81), 1,
      sym_element,
    STATE(12), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [386] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(83), 3,
      anon_sym_EQ,
      anon_sym_LBRACE,
      sym_quoted_string,
    ACTIONS(85), 4,
      sym_word,
      sym_string,
      sym_float,
      sym_integer,
  [401] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(87), 1,
      anon_sym_COMMA,
    ACTIONS(90), 1,
      anon_sym_RBRACE,
    ACTIONS(92), 2,
      sym_float,
      sym_integer,
    STATE(17), 2,
      sym_brace_value,
      aux_sym_brace_content_repeat1,
  [419] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(95), 1,
      anon_sym_xyz,
    ACTIONS(97), 1,
      anon_sym_int,
    ACTIONS(99), 1,
      anon_sym_gzmt,
    STATE(132), 1,
      sym_geom_line_types,
    ACTIONS(101), 2,
      anon_sym_xyzfile,
      anon_sym_gzmtfile,
  [439] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(103), 1,
      anon_sym_COMMA,
    ACTIONS(105), 1,
      anon_sym_RBRACE,
    ACTIONS(107), 2,
      sym_float,
      sym_integer,
    STATE(17), 2,
      sym_brace_value,
      aux_sym_brace_content_repeat1,
  [457] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(103), 1,
      anon_sym_COMMA,
    ACTIONS(109), 1,
      anon_sym_RBRACE,
    ACTIONS(107), 2,
      sym_float,
      sym_integer,
    STATE(19), 2,
      sym_brace_value,
      aux_sym_brace_content_repeat1,
  [475] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(115), 1,
      anon_sym_COMMA,
    STATE(25), 1,
      aux_sym_value_repeat1,
    ACTIONS(111), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(113), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [493] = 7,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(117), 1,
      anon_sym_LF,
    ACTIONS(119), 1,
      anon_sym_LBRACE,
    ACTIONS(121), 1,
      sym_float,
    ACTIONS(123), 1,
      sym_integer,
    STATE(49), 1,
      sym_coord_value,
    STATE(95), 1,
      sym_variable_ref,
  [515] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(77), 1,
      sym_element,
    STATE(14), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [529] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(129), 1,
      anon_sym_LBRACK,
    ACTIONS(125), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(127), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [545] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_COMMA,
    STATE(25), 1,
      aux_sym_value_repeat1,
    ACTIONS(131), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(133), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [563] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(115), 1,
      anon_sym_COMMA,
    STATE(21), 1,
      aux_sym_value_repeat1,
    ACTIONS(138), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(140), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [581] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(142), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(144), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [594] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(148), 1,
      anon_sym_SEMI,
    ACTIONS(150), 1,
      anon_sym_COMMA,
    ACTIONS(152), 1,
      anon_sym_LBRACE,
    ACTIONS(146), 2,
      anon_sym_end,
      sym_word,
  [611] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(154), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(156), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [624] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(158), 1,
      anon_sym_RBRACE,
    STATE(20), 1,
      sym_brace_value,
    STATE(128), 1,
      sym_brace_content,
    ACTIONS(107), 2,
      sym_float,
      sym_integer,
  [641] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(162), 3,
      anon_sym_LBRACE,
      sym_quoted_string,
      sym_float,
  [654] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(166), 1,
      sym_element,
    ACTIONS(164), 2,
      anon_sym_end,
      anon_sym_STAR,
    STATE(32), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [669] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(127), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [682] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(131), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(133), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [695] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(169), 1,
      anon_sym_LBRACE,
    ACTIONS(171), 1,
      sym_float,
    ACTIONS(173), 1,
      sym_integer,
    STATE(94), 1,
      sym_coord_value,
    STATE(97), 1,
      sym_variable_ref,
  [714] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(177), 1,
      sym_element,
    ACTIONS(175), 2,
      anon_sym_end,
      anon_sym_STAR,
    STATE(36), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [729] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(85), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(83), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [742] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(180), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_PERCENT,
      anon_sym_STAR,
  [752] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(182), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_PERCENT,
      anon_sym_STAR,
  [762] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(186), 1,
      anon_sym_SEMI,
    ACTIONS(188), 1,
      anon_sym_LBRACE,
    ACTIONS(184), 2,
      anon_sym_end,
      sym_word,
  [776] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(190), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_PERCENT,
      anon_sym_STAR,
  [786] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(194), 1,
      anon_sym_SEMI,
    ACTIONS(196), 1,
      anon_sym_LBRACE,
    ACTIONS(192), 2,
      anon_sym_end,
      sym_word,
  [800] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(79), 1,
      anon_sym_end,
    ACTIONS(198), 1,
      sym_element,
    STATE(32), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [814] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(79), 1,
      anon_sym_end,
    ACTIONS(200), 1,
      sym_element,
    STATE(36), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [828] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(148), 1,
      anon_sym_SEMI,
    ACTIONS(152), 1,
      anon_sym_LBRACE,
    ACTIONS(146), 2,
      anon_sym_end,
      sym_word,
  [842] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(204), 1,
      anon_sym_SEMI,
    ACTIONS(206), 1,
      anon_sym_LBRACE,
    ACTIONS(202), 2,
      anon_sym_end,
      sym_word,
  [856] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(208), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_PERCENT,
      anon_sym_STAR,
  [866] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(90), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(210), 2,
      sym_float,
      sym_integer,
  [878] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(212), 1,
      anon_sym_LBRACE,
    ACTIONS(214), 1,
      sym_float,
    STATE(56), 1,
      sym_coord_value,
    STATE(95), 1,
      sym_variable_ref,
  [894] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(212), 1,
      anon_sym_LBRACE,
    ACTIONS(214), 1,
      sym_float,
    STATE(49), 1,
      sym_coord_value,
    STATE(95), 1,
      sym_variable_ref,
  [910] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(216), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(218), 2,
      sym_float,
      sym_integer,
  [922] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(220), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(222), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [934] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(75), 1,
      anon_sym_STAR,
    ACTIONS(224), 1,
      sym_element,
    STATE(32), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [948] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(75), 1,
      anon_sym_STAR,
    ACTIONS(226), 1,
      sym_element,
    STATE(36), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [962] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(228), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_PERCENT,
      anon_sym_STAR,
  [972] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(169), 1,
      anon_sym_LBRACE,
    ACTIONS(230), 1,
      sym_float,
    STATE(97), 1,
      sym_variable_ref,
    STATE(116), 1,
      sym_coord_value,
  [988] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(169), 1,
      anon_sym_LBRACE,
    ACTIONS(230), 1,
      sym_float,
    STATE(94), 1,
      sym_coord_value,
    STATE(97), 1,
      sym_variable_ref,
  [1004] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(232), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(234), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [1016] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(212), 1,
      anon_sym_LBRACE,
    ACTIONS(214), 1,
      sym_float,
    STATE(62), 1,
      sym_coord_value,
    STATE(95), 1,
      sym_variable_ref,
  [1032] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(169), 1,
      anon_sym_LBRACE,
    ACTIONS(230), 1,
      sym_float,
    STATE(96), 1,
      sym_coord_value,
    STATE(97), 1,
      sym_variable_ref,
  [1048] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(236), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_PERCENT,
      anon_sym_STAR,
  [1058] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(212), 1,
      anon_sym_LBRACE,
    ACTIONS(214), 1,
      sym_float,
    STATE(64), 1,
      sym_coord_value,
    STATE(95), 1,
      sym_variable_ref,
  [1074] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(238), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(240), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [1086] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(169), 1,
      anon_sym_LBRACE,
    ACTIONS(230), 1,
      sym_float,
    STATE(97), 1,
      sym_variable_ref,
    STATE(126), 1,
      sym_coord_value,
  [1102] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(169), 1,
      anon_sym_LBRACE,
    ACTIONS(230), 1,
      sym_float,
    STATE(97), 1,
      sym_variable_ref,
    STATE(102), 1,
      sym_coord_value,
  [1118] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(242), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_PERCENT,
      anon_sym_STAR,
  [1128] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(246), 1,
      sym_element,
    ACTIONS(244), 2,
      anon_sym_end,
      anon_sym_STAR,
  [1139] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(224), 1,
      sym_element,
    STATE(53), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [1150] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(226), 1,
      sym_element,
    STATE(54), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [1161] = 4,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(248), 1,
      anon_sym_LF,
    ACTIONS(250), 1,
      sym_arg,
    STATE(70), 1,
      aux_sym_simple_line_repeat1,
  [1174] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(255), 1,
      sym_element,
    ACTIONS(253), 2,
      anon_sym_end,
      anon_sym_STAR,
  [1185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(259), 1,
      anon_sym_LBRACE,
    ACTIONS(257), 2,
      anon_sym_end,
      sym_word,
  [1196] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(263), 1,
      anon_sym_LBRACE,
    ACTIONS(261), 2,
      anon_sym_end,
      sym_word,
  [1207] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(265), 1,
      anon_sym_RBRACK,
    ACTIONS(267), 1,
      sym_float,
    STATE(80), 1,
      aux_sym_variable_array_repeat1,
  [1220] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(271), 1,
      anon_sym_LBRACE,
    ACTIONS(269), 2,
      anon_sym_end,
      sym_word,
  [1231] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(273), 1,
      anon_sym_EQ,
    ACTIONS(275), 1,
      anon_sym_LBRACK,
    STATE(40), 1,
      sym_variable_array,
  [1244] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(48), 1,
      sym_brace_value,
    ACTIONS(107), 2,
      sym_float,
      sym_integer,
  [1255] = 4,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(277), 1,
      anon_sym_LF,
    ACTIONS(279), 1,
      sym_arg,
    STATE(70), 1,
      aux_sym_simple_line_repeat1,
  [1268] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(206), 1,
      anon_sym_LBRACE,
    ACTIONS(202), 2,
      anon_sym_end,
      sym_word,
  [1279] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(281), 1,
      anon_sym_RBRACK,
    ACTIONS(283), 1,
      sym_float,
    STATE(80), 1,
      aux_sym_variable_array_repeat1,
  [1292] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(288), 1,
      sym_element,
    ACTIONS(286), 2,
      anon_sym_end,
      anon_sym_STAR,
  [1303] = 4,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(290), 1,
      anon_sym_LF,
    ACTIONS(292), 1,
      sym_arg,
    STATE(78), 1,
      aux_sym_simple_line_repeat1,
  [1316] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(296), 1,
      anon_sym_LBRACE,
    ACTIONS(294), 2,
      anon_sym_end,
      sym_word,
  [1327] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(300), 1,
      sym_element,
    ACTIONS(298), 2,
      anon_sym_end,
      anon_sym_STAR,
  [1338] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(304), 1,
      sym_element,
    ACTIONS(302), 2,
      anon_sym_end,
      anon_sym_STAR,
  [1349] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(306), 1,
      anon_sym_RBRACK,
    ACTIONS(308), 1,
      sym_float,
    STATE(74), 1,
      aux_sym_variable_array_repeat1,
  [1362] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(310), 1,
      sym_float,
    ACTIONS(312), 1,
      sym_integer,
    STATE(45), 1,
      sym_variable_range,
  [1375] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(316), 1,
      sym_element,
    ACTIONS(314), 2,
      anon_sym_end,
      anon_sym_STAR,
  [1386] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(152), 1,
      anon_sym_LBRACE,
    ACTIONS(146), 2,
      anon_sym_end,
      sym_word,
  [1397] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(320), 1,
      anon_sym_LBRACE,
    ACTIONS(318), 2,
      anon_sym_end,
      sym_word,
  [1408] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      sym_word,
    STATE(118), 1,
      sym_variable_name,
  [1418] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(324), 2,
      anon_sym_LBRACE,
      sym_float,
  [1426] = 3,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(117), 1,
      anon_sym_LF,
    ACTIONS(326), 1,
      sym_integer,
  [1436] = 3,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(328), 1,
      anon_sym_LF,
    ACTIONS(330), 1,
      sym_integer,
  [1446] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(332), 2,
      anon_sym_LBRACE,
      sym_float,
  [1454] = 3,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(334), 1,
      anon_sym_LF,
    ACTIONS(336), 1,
      sym_integer,
  [1464] = 3,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(332), 1,
      anon_sym_LF,
    ACTIONS(338), 1,
      sym_integer,
  [1474] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(340), 2,
      sym_string,
      sym_integer,
  [1482] = 3,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(324), 1,
      anon_sym_LF,
    ACTIONS(342), 1,
      sym_integer,
  [1492] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(344), 2,
      sym_string,
      sym_integer,
  [1500] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      sym_word,
    STATE(134), 1,
      sym_variable_name,
  [1510] = 2,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(346), 1,
      anon_sym_LF,
  [1517] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(348), 1,
      sym_integer,
  [1524] = 2,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(350), 1,
      anon_sym_LF,
  [1531] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(352), 1,
      sym_integer,
  [1538] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(354), 1,
      sym_integer,
  [1545] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(356), 1,
      sym_word,
  [1552] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(358), 1,
      anon_sym_COMMA,
  [1559] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(79), 1,
      anon_sym_end,
  [1566] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(360), 1,
      sym_integer,
  [1573] = 2,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(362), 1,
      anon_sym_LF,
  [1580] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(364), 1,
      sym_integer,
  [1587] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(366), 1,
      sym_float,
  [1594] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym_integer,
  [1601] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      sym_integer,
  [1608] = 2,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(372), 1,
      anon_sym_LF,
  [1615] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(374), 1,
      sym_float,
  [1622] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(376), 1,
      anon_sym_RBRACE,
  [1629] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(378), 1,
      anon_sym_RBRACK,
  [1636] = 2,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(380), 1,
      anon_sym_LF,
  [1643] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(382), 1,
      sym_float,
  [1650] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(384), 1,
      sym_integer,
  [1657] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(386), 1,
      ts_builtin_sym_end,
  [1664] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(388), 1,
      sym_file,
  [1671] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(390), 1,
      sym_integer,
  [1678] = 2,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(392), 1,
      anon_sym_LF,
  [1685] = 2,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(394), 1,
      anon_sym_LF,
  [1692] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(396), 1,
      anon_sym_RBRACE,
  [1699] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(398), 1,
      sym_integer,
  [1706] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(400), 1,
      sym_integer,
  [1713] = 2,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(402), 1,
      anon_sym_LF,
  [1720] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(404), 1,
      sym_integer,
  [1727] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(406), 1,
      anon_sym_RBRACK,
  [1734] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(408), 1,
      anon_sym_RBRACE,
  [1741] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(410), 1,
      anon_sym_end,
  [1748] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(412), 1,
      anon_sym_RBRACE,
  [1755] = 2,
    ACTIONS(66), 1,
      sym_comment,
    ACTIONS(414), 1,
      anon_sym_LF,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 53,
  [SMALL_STATE(4)] = 92,
  [SMALL_STATE(5)] = 121,
  [SMALL_STATE(6)] = 150,
  [SMALL_STATE(7)] = 182,
  [SMALL_STATE(8)] = 214,
  [SMALL_STATE(9)] = 245,
  [SMALL_STATE(10)] = 273,
  [SMALL_STATE(11)] = 294,
  [SMALL_STATE(12)] = 319,
  [SMALL_STATE(13)] = 337,
  [SMALL_STATE(14)] = 352,
  [SMALL_STATE(15)] = 369,
  [SMALL_STATE(16)] = 386,
  [SMALL_STATE(17)] = 401,
  [SMALL_STATE(18)] = 419,
  [SMALL_STATE(19)] = 439,
  [SMALL_STATE(20)] = 457,
  [SMALL_STATE(21)] = 475,
  [SMALL_STATE(22)] = 493,
  [SMALL_STATE(23)] = 515,
  [SMALL_STATE(24)] = 529,
  [SMALL_STATE(25)] = 545,
  [SMALL_STATE(26)] = 563,
  [SMALL_STATE(27)] = 581,
  [SMALL_STATE(28)] = 594,
  [SMALL_STATE(29)] = 611,
  [SMALL_STATE(30)] = 624,
  [SMALL_STATE(31)] = 641,
  [SMALL_STATE(32)] = 654,
  [SMALL_STATE(33)] = 669,
  [SMALL_STATE(34)] = 682,
  [SMALL_STATE(35)] = 695,
  [SMALL_STATE(36)] = 714,
  [SMALL_STATE(37)] = 729,
  [SMALL_STATE(38)] = 742,
  [SMALL_STATE(39)] = 752,
  [SMALL_STATE(40)] = 762,
  [SMALL_STATE(41)] = 776,
  [SMALL_STATE(42)] = 786,
  [SMALL_STATE(43)] = 800,
  [SMALL_STATE(44)] = 814,
  [SMALL_STATE(45)] = 828,
  [SMALL_STATE(46)] = 842,
  [SMALL_STATE(47)] = 856,
  [SMALL_STATE(48)] = 866,
  [SMALL_STATE(49)] = 878,
  [SMALL_STATE(50)] = 894,
  [SMALL_STATE(51)] = 910,
  [SMALL_STATE(52)] = 922,
  [SMALL_STATE(53)] = 934,
  [SMALL_STATE(54)] = 948,
  [SMALL_STATE(55)] = 962,
  [SMALL_STATE(56)] = 972,
  [SMALL_STATE(57)] = 988,
  [SMALL_STATE(58)] = 1004,
  [SMALL_STATE(59)] = 1016,
  [SMALL_STATE(60)] = 1032,
  [SMALL_STATE(61)] = 1048,
  [SMALL_STATE(62)] = 1058,
  [SMALL_STATE(63)] = 1074,
  [SMALL_STATE(64)] = 1086,
  [SMALL_STATE(65)] = 1102,
  [SMALL_STATE(66)] = 1118,
  [SMALL_STATE(67)] = 1128,
  [SMALL_STATE(68)] = 1139,
  [SMALL_STATE(69)] = 1150,
  [SMALL_STATE(70)] = 1161,
  [SMALL_STATE(71)] = 1174,
  [SMALL_STATE(72)] = 1185,
  [SMALL_STATE(73)] = 1196,
  [SMALL_STATE(74)] = 1207,
  [SMALL_STATE(75)] = 1220,
  [SMALL_STATE(76)] = 1231,
  [SMALL_STATE(77)] = 1244,
  [SMALL_STATE(78)] = 1255,
  [SMALL_STATE(79)] = 1268,
  [SMALL_STATE(80)] = 1279,
  [SMALL_STATE(81)] = 1292,
  [SMALL_STATE(82)] = 1303,
  [SMALL_STATE(83)] = 1316,
  [SMALL_STATE(84)] = 1327,
  [SMALL_STATE(85)] = 1338,
  [SMALL_STATE(86)] = 1349,
  [SMALL_STATE(87)] = 1362,
  [SMALL_STATE(88)] = 1375,
  [SMALL_STATE(89)] = 1386,
  [SMALL_STATE(90)] = 1397,
  [SMALL_STATE(91)] = 1408,
  [SMALL_STATE(92)] = 1418,
  [SMALL_STATE(93)] = 1426,
  [SMALL_STATE(94)] = 1436,
  [SMALL_STATE(95)] = 1446,
  [SMALL_STATE(96)] = 1454,
  [SMALL_STATE(97)] = 1464,
  [SMALL_STATE(98)] = 1474,
  [SMALL_STATE(99)] = 1482,
  [SMALL_STATE(100)] = 1492,
  [SMALL_STATE(101)] = 1500,
  [SMALL_STATE(102)] = 1510,
  [SMALL_STATE(103)] = 1517,
  [SMALL_STATE(104)] = 1524,
  [SMALL_STATE(105)] = 1531,
  [SMALL_STATE(106)] = 1538,
  [SMALL_STATE(107)] = 1545,
  [SMALL_STATE(108)] = 1552,
  [SMALL_STATE(109)] = 1559,
  [SMALL_STATE(110)] = 1566,
  [SMALL_STATE(111)] = 1573,
  [SMALL_STATE(112)] = 1580,
  [SMALL_STATE(113)] = 1587,
  [SMALL_STATE(114)] = 1594,
  [SMALL_STATE(115)] = 1601,
  [SMALL_STATE(116)] = 1608,
  [SMALL_STATE(117)] = 1615,
  [SMALL_STATE(118)] = 1622,
  [SMALL_STATE(119)] = 1629,
  [SMALL_STATE(120)] = 1636,
  [SMALL_STATE(121)] = 1643,
  [SMALL_STATE(122)] = 1650,
  [SMALL_STATE(123)] = 1657,
  [SMALL_STATE(124)] = 1664,
  [SMALL_STATE(125)] = 1671,
  [SMALL_STATE(126)] = 1678,
  [SMALL_STATE(127)] = 1685,
  [SMALL_STATE(128)] = 1692,
  [SMALL_STATE(129)] = 1699,
  [SMALL_STATE(130)] = 1706,
  [SMALL_STATE(131)] = 1713,
  [SMALL_STATE(132)] = 1720,
  [SMALL_STATE(133)] = 1727,
  [SMALL_STATE(134)] = 1734,
  [SMALL_STATE(135)] = 1741,
  [SMALL_STATE(136)] = 1748,
  [SMALL_STATE(137)] = 1755,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(90),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(41),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [25] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [27] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(82),
  [30] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(107),
  [33] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(18),
  [36] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [38] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_input_body_repeat1, 2, 0, 0),
  [40] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_input_body_repeat1, 2, 0, 0), SHIFT_REPEAT(30),
  [43] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_input_body_repeat1, 2, 0, 0), SHIFT_REPEAT(10),
  [46] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_body, 1, 0, 0),
  [48] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [50] = {.entry = {.count = 1, .reusable = false}}, SHIFT(24),
  [52] = {.entry = {.count = 1, .reusable = false}}, SHIFT(33),
  [54] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [56] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [58] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_variable_name, 1, 0, 0), REDUCE(sym_input_key, 1, 0, 0),
  [61] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_variable_name, 1, 0, 0), SHIFT(98),
  [64] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_key, 1, 0, 0),
  [66] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [68] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subblock_repeat3, 2, 0, 0),
  [70] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subblock_repeat3, 2, 0, 0), SHIFT_REPEAT(93),
  [73] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_key, 1, 0, 0),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(93),
  [83] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 4, 0, 0),
  [85] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 4, 0, 0),
  [87] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_brace_content_repeat1, 2, 0, 0), SHIFT_REPEAT(77),
  [90] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_brace_content_repeat1, 2, 0, 0),
  [92] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_brace_content_repeat1, 2, 0, 0), SHIFT_REPEAT(51),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(122),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(115),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_brace_content, 2, 0, 0),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(51),
  [109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_brace_content, 1, 0, 0),
  [111] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value, 2, 0, 0),
  [113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value, 2, 0, 0),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(91),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(95),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_atom, 1, 0, 0),
  [127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_atom, 1, 0, 0),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_value_repeat1, 2, 0, 0),
  [133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_value_repeat1, 2, 0, 0),
  [135] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_repeat1, 2, 0, 0), SHIFT_REPEAT(11),
  [138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value, 1, 0, 0),
  [140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value, 1, 0, 0),
  [142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_brace_block, 2, 0, 0),
  [144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_brace_block, 2, 0, 0),
  [146] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_def, 3, 0, 0),
  [148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_def, 3, 0, 0),
  [154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_brace_block, 3, 0, 0),
  [156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_brace_block, 3, 0, 0),
  [158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_title, 2, 0, 0),
  [162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_title, 2, 0, 0),
  [164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subblock_repeat1, 2, 0, 0),
  [166] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subblock_repeat1, 2, 0, 0), SHIFT_REPEAT(50),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(97),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(103),
  [175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subblock_repeat2, 2, 0, 0),
  [177] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subblock_repeat2, 2, 0, 0), SHIFT_REPEAT(110),
  [180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_line, 2, 0, 0),
  [182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_block, 3, 0, 0),
  [184] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_def, 2, 0, 0),
  [186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_def, 2, 0, 0),
  [190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_block, 2, 0, 0),
  [192] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_kv_pair, 2, 0, 0),
  [194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kv_pair, 2, 0, 0),
  [198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(50),
  [200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(110),
  [202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_kv_pair, 3, 0, 0),
  [204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kv_pair, 3, 0, 0),
  [208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_line, 3, 0, 0),
  [210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_brace_content_repeat1, 2, 0, 0),
  [212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_brace_value, 1, 0, 0),
  [218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_brace_value, 1, 0, 0),
  [220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_array, 3, 0, 0),
  [222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_array, 3, 0, 0),
  [224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_geom_line, 6, 0, 0),
  [230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [232] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_array, 4, 0, 0),
  [234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_array, 4, 0, 0),
  [236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_geom_block, 8, 0, 0),
  [238] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_range, 5, 0, 0),
  [240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_range, 5, 0, 0),
  [242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_line, 3, 0, 0),
  [244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_zmat_line4, 8, 0, 5),
  [246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_zmat_line4, 8, 0, 5),
  [248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_simple_line_repeat1, 2, 0, 0),
  [250] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_simple_line_repeat1, 2, 0, 0), SHIFT_REPEAT(70),
  [253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_zmat_line1, 2, 0, 0),
  [255] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_zmat_line1, 2, 0, 0),
  [257] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subblock, 4, 2, 1),
  [259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subblock, 4, 2, 1),
  [261] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_def, 4, 0, 0),
  [263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_def, 4, 0, 0),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [269] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_kv_pair, 4, 0, 0),
  [271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kv_pair, 4, 0, 0),
  [273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_array_repeat1, 2, 0, 0),
  [283] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_array_repeat1, 2, 0, 0), SHIFT_REPEAT(80),
  [286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_zmat_line2, 4, 0, 2),
  [288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_zmat_line2, 4, 0, 2),
  [290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(78),
  [294] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_raw_content, 1, 0, 0),
  [296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raw_content, 1, 0, 0),
  [298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xyz_line, 5, 0, 0),
  [300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_xyz_line, 5, 0, 0),
  [302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_zmat_line3, 6, 0, 3),
  [304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_zmat_line3, 6, 0, 3),
  [306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(45),
  [314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_int_line, 8, 0, 4),
  [316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_int_line, 8, 0, 4),
  [318] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subblock, 3, 2, 1),
  [320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subblock, 3, 2, 1),
  [322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_ref, 3, 0, 0),
  [326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_coord_value, 1, 0, 0),
  [334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(65),
  [338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_coord_value, 1, 0, 0),
  [340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_ref, 3, 0, 0),
  [344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [386] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_geom_line_types, 1, 0, 0),
  [400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_name, 1, 0, 0),
  [414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_orca(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
    .name = "orca",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 1,
      .patch_version = 0,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
